/**
 * my.js : template loader and renderer. 
 */

var iplus = {};

//usage :
//my.renderer.load(templateName);
// for output-only templates:
//my.renderer.render(templateName, containerSelector, data, pre_subsitutions);
// alternatively, for form-like templates (I/O)
//my.renderer.link(templateName, containerSelector, data);
iplus.renderer = (function() {
	var formatTemplatePath = function(name) {
		return "templates/_" + name + ".tmpl.html";
	}, renderTemplate = function(tmplName, targetSelector, data,
			pre_substitutions) {
		var file = formatTemplatePath(tmplName);
		$.get(file, null, function(template) {

			if(pre_substitutions) {
				for (var name in pre_substitutions) {
					var regex = new RegExp(name, 'g');
					template = template.replace(regex, pre_substitutions[name]);
				}
			}

			$.templates[tmplName] = template;
			var tmpl = $.templates(template);
			var htmlString = tmpl.render(data);
			if (targetSelector) {
				$(targetSelector).append(htmlString);
			}
			return htmlString;
		});
	},  loadTemplate = function(tmplName) {
		var file = formatTemplatePath(tmplName);
		$.get(file, null, function(template) {
			$.templates[tmplName] = template;
			$.templates(template);
		});
	}, linkFormTemplate = function(tmplName, targetSelector, data) {
		
		renderTemplate(tmplName, targetSelector, data);
		
		var file = formatTemplatePath(tmplName);
		$.get(file, null, function(template) {
			$.templates[tmplName] = template;
			var tmpl = $.templates(template);
			
			if (targetSelector) {
				$.templates[tmplName].link($(targetSelector), data);
				$.link(true,targetSelector,data)
			}
		});
	}, refreshTemplate = function(tmplName, targetSelector, data,
			pre_substitutions) {
		$(targetSelector).empty();
		renderTemplate(tmplName, targetSelector, data,
			pre_substitutions);
	};
	return {
		render : renderTemplate,
		link : linkFormTemplate,
		load : loadTemplate,
		refresh : refreshTemplate
	};
})() 
